#
# spec file for package libvsg
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _check 0
%define _vsg_so_nr 14
%define rname VulkanSceneGraph
%define glslang_version 20230222+git.e4075496

Name:           libvsg
Version:        1.0.9
Release:        1.2
Summary:        3D graphics toolkit
License:        MIT
Group:          Productivity/Graphics/Other
URL:            https://vsg-dev.github.io/VulkanSceneGraph
Source0:        %{rname}-%{version}.tar.xz
Source1:        glslang-%{glslang_version}.tar.xz
BuildRequires:  cmake
BuildRequires:  gcc-c++
%if %_check
BuildRequires:  cppcheck
%endif
BuildRequires:  cmake(SPIRV-Tools)
BuildRequires:  pkgconfig(vulkan)
BuildRequires:  pkgconfig(xcb)

%description
The VulkanSceneGraph is a graphics toolkit for the development of
graphic applications such as flight simulators, games, virtual
reality and scientific visualization. Based around the concept of a
scene graph, it provides an object-oriented framework on top of
Vulkan freeing the developer from implementing and optimizing low
level graphics calls, and provides many additional utilities for
development of graphics applications.

%package -n libvsg%{_vsg_so_nr}
Summary:        Shared libraries for VulkanSceneGraph
# try to cover up past mistakes
Group:          System/Libraries

%description -n libvsg%{_vsg_so_nr}
The VulkanSceneGraph is a graphics toolkit for the development of
graphic applications such as flight simulators, games, virtual
reality and scientific visualization. Based around the concept of a
scene graph, it provides an object-oriented framework on top of
Vulkan.

This package contains the shared libraries for VulkanSceneGraph.

%package -n libvsg-devel
Summary:        VulkanSceneGraph development files
Group:          Development/Libraries/C and C++
Requires:       libvsg%{_vsg_so_nr} = %{version}
Requires:       pkgconfig(vulkan)

%description -n libvsg-devel
The VulkanSceneGraph is a graphics toolkit for the development of
graphic applications such as flight simulators, games, virtual
reality and scientific visualization. Based around the concept of a
scene graph, it provides an object-oriented framework on top of
OpenGL.

This package contains the header and development files for
VulkanSceneGraph.

%prep
%autosetup -p1 -n %{rname}-%{version}
tar -xJf %{SOURCE1}
mv glslang-%{glslang_version} src/glslang

%build
%cmake -DBUILD_SHARED_LIBS=ON -DCMAKE_RELWITHDEBINFO_POSTFIX=
%cmake_build

%check
%if %_check
cppcheck --version
cd build && make cppcheck
%endif

%install
%cmake_install

%post -n libvsg%{_vsg_so_nr} -p /sbin/ldconfig
%postun -n libvsg%{_vsg_so_nr} -p /sbin/ldconfig

%files -n libvsg%{_vsg_so_nr}
%defattr(-,root,root)
%license LICENSE.md
%{_libdir}/lib*.so.*

%files -n libvsg-devel
%defattr(-,root,root)
%{_includedir}/vsg*/
%{_libdir}/lib*.so
%{_libdir}/cmake

%changelog
* Fri Sep 15 2023 Ralf Habacker <ralf.habacker@freenet.de>
- Update to version 1.0.9
  * See https://github.com/vsg-dev/VulkanSceneGraph/releases/tag/v1.0.9
    for release info
* Thu Aug  3 2023 Ralf Habacker <ralf.habacker@freenet.de>
- Dropped obsolete dependendy to glslang from development package
  which fixes adding to SLE backports, see
  https://build.opensuse.org/request/show/1106938#comment-1818352
* Tue Aug  1 2023 Ralf Habacker <ralf.habacker@freenet.de>
- Update to version 1.0.8
  * Update soversion to 14
  * See https://github.com/vsg-dev/VulkanSceneGraph/releases/tag/v1.0.8
    for release info
* Thu Jun 22 2023 Ralf Habacker <ralf.habacker@freenet.de>
- Update to version 1.0.7
* Tue Apr 25 2023 Ralf Habacker <ralf.habacker@freenet.de>
- Update to version 1.0.5
- Drop obsolete patch
  * VulkanSceneGraph-1.0.4-fix-building-with-gcc13.patch
- Followed upstream dropping submodule support for glslang
  and add that package as regular tarball
* Wed Mar 22 2023 Ralf Habacker <ralf.habacker@freenet.de>
- Update to version 1.0.4
- Tar ball needs to be generated by _service file as the raw tarball
  does not include the embedded git submodule
- Add patch
  * VulkanSceneGraph-1.0.4-fix-building-with-gcc13.patch
  to fix building on Tumbleweed with gcc 13
* Tue Mar 14 2023 Ralf Habacker <ralf.habacker@freenet.de>
- Udate to version 1.0.3
- Drop obsolete build dependency to glslang as it is now embedded
- Drop obsolete patch
  * 0002-Fix-compiling-with-MinGW.patch
* Wed Feb 22 2023 Ralf Habacker <ralf.habacker@freenet.de>
- Drop url from Source: tag to fix https://github.com/openSUSE/osc/issues/1268
* Mon Dec 12 2022 Ralf Habacker <ralf.habacker@freenet.de>
- Update to version 1.0.2
- Add patch
  * 0002-Fix-compiling-with-MinGW.patch
* Thu Nov 17 2022 Ralf Habacker <ralf.habacker@freenet.de>
- Update to version 1.0.0
* Tue Aug 17 2021 Ralf Habacker <ralf.habacker@freenet.de>
- Initial package
